"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SUPPORTED_LIQUID_DOC_TAG_HANDLES = exports.formatLiquidDocTagHandle = exports.formatLiquidDocParameter = void 0;
const theme_check_common_1 = require("@shopify/theme-check-common");
function formatLiquidDocParameter({ name, type, description, required }, heading = false) {
    const nameStr = required ? `\`${name}\`` : `\`${name}\` (Optional)`;
    const typeStr = type ? `: ${type}` : '';
    if (heading) {
        const descStr = description ? `\n\n${description}` : '';
        return `### ${nameStr}${typeStr}${descStr}`;
    }
    const descStr = description ? ` - ${description}` : '';
    return `- ${nameStr}${typeStr}${descStr}`;
}
exports.formatLiquidDocParameter = formatLiquidDocParameter;
function formatLiquidDocTagHandle(label, description, example) {
    return `### @${label}\n\n${description}\n\n` + `**Example**\n\n\`\`\`liquid\n${example}\n\`\`\``;
}
exports.formatLiquidDocTagHandle = formatLiquidDocTagHandle;
exports.SUPPORTED_LIQUID_DOC_TAG_HANDLES = {
    [theme_check_common_1.SupportedDocTagTypes.Param]: {
        description: 'Provides information about a parameter for the snippet.\n' +
            `- The type of parameter is optional and can be ${Object.values(theme_check_common_1.SupportedParamTypes)
                .map((type) => `\`${type}\``)
                .join(', ')}\n` +
            '- An optional parameter is denoted by square brackets around the parameter name\n' +
            '- The description is optional Markdown text',
        example: '{% doc %}\n' +
            "  @param {string} name - The person's name\n" +
            "  @param {number} [fav_num] - The person's favorite number\n" +
            '{% enddoc %}\n',
        template: `param {$2} $1 - $0`,
    },
    [theme_check_common_1.SupportedDocTagTypes.Example]: {
        description: 'Provides an example on how to use the snippet.',
        example: '{% doc %}\n' + '  @example {% render "snippet-name", arg1: "value" %}\n' + '{% enddoc %}\n',
        template: `example $0`,
    },
    [theme_check_common_1.SupportedDocTagTypes.Description]: {
        description: 'Provides information on what the snippet does.',
        example: '{% doc %}\n' + '  @description This snippet renders a product image.\n' + '{% enddoc %}\n',
        template: `description $0`,
    },
};
//# sourceMappingURL=liquidDoc.js.map